﻿using Microsoft.AspNetCore.Mvc;
using System.Collections.Generic;
using System.Threading.Tasks;

using TestProject.Models;

namespace TestProject.ViewComponents
{
    /// <summary>
    /// 데이터 리스트 뷰 컴포넌트
    /// </summary>
    public class DataListViewComponent : ViewComponent
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 비동기 호출하기 - InvokeAsync(name)

        /// <summary>
        /// 비동기 호출하기
        /// </summary>
        /// <param name="name">성명</param>
        /// <returns>뷰 컴포넌트 결과 태스크</returns>
        public async Task<IViewComponentResult> InvokeAsync(string name)
        {
            List<DataModel> list = await GetListAsync(name);

            return View(list);
        }

        #endregion

        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 리스트 비동기 구하기 - GetListAsync(name)

        /// <summary>
        /// 리스트 비동기 구하기
        /// </summary>
        /// <param name="name">성명</param>
        /// <returns>리스트 태스크</returns>
        private Task<List<DataModel>> GetListAsync(string name)
        {
            return Task.FromResult(GetList(name));
        }

        #endregion
        #region 리스트 구하기 - GetList(name)

        /// <summary>
        /// 리스트 구하기
        /// </summary>
        /// <param name="name">성명</param>
        /// <returns>리스트</returns>
        private List<DataModel> GetList(string name)
        {
            DataRepository repository = new DataRepository();

            return repository.GetList(name);
        }

        #endregion
    }
}